@@ -4,6 +4,7 @@
 #include <engine/storage.h>
 #include <engine/client.h>
 #include <engine/external/json-parser/json.h>
+#include <engine/shared/json.h>
 #include <game/version.h>
 
 #include <stdlib.h> // system
@@ -85,6 +86,9 @@ CUpdater::CUpdater()
 	m_State = CLEAN;
 	m_Percent = 0;
 	m_Lock = lock_create();
+
+	str_format(m_aClientExecTmp, sizeof(m_aClientExecTmp), CLIENT_EXEC ".%d.tmp", pid());
+	str_format(m_aServerExecTmp, sizeof(m_aServerExecTmp), SERVER_EXEC ".%d.tmp", pid());
 }
 
 void CUpdater::Init()
@@ -186,23 +190,24 @@ bool CUpdater::ReplaceClient()
 {
 	dbg_msg("updater", "replacing " PLAT_CLIENT_EXEC);
 	bool Success = true;
+	char aPath[512];
 
 	// Replace running executable by renaming twice...
 	if(!m_IsWinXP)
 	{
-		m_pStorage->RemoveBinaryFile("DDNet.old");
-		Success &= m_pStorage->RenameBinaryFile(PLAT_CLIENT_EXEC, "DDNet.old");
-		Success &= m_pStorage->RenameBinaryFile("update/DDNet.tmp", PLAT_CLIENT_EXEC);
+		m_pStorage->RemoveBinaryFile(CLIENT_EXEC ".old");
+		Success &= m_pStorage->RenameBinaryFile(PLAT_CLIENT_EXEC, CLIENT_EXEC ".old");
+		str_format(aPath, sizeof(aPath), "update/%s", m_aClientExecTmp);
+		Success &= m_pStorage->RenameBinaryFile(aPath, PLAT_CLIENT_EXEC);
 	}
 	#if !defined(CONF_FAMILY_WINDOWS)
-		char aPath[512];
 		m_pStorage->GetBinaryPath(PLAT_CLIENT_EXEC, aPath, sizeof aPath);
 		char aBuf[512];
 		str_format(aBuf, sizeof aBuf, "chmod +x %s", aPath);
 		if(system(aBuf))
 		{
 			dbg_msg("updater", "ERROR: failed to set client executable bit");
-			Success &= false;
+			Success = false;
 		}
 	#endif
 	return Success;
@@ -212,20 +217,21 @@ bool CUpdater::ReplaceServer()
 {
 	dbg_msg("updater", "replacing " PLAT_SERVER_EXEC);
 	bool Success = true;
+	char aPath[512];
 
 	//Replace running executable by renaming twice...
-	m_pStorage->RemoveBinaryFile("DDNet-Server.old");
-	Success &= m_pStorage->RenameBinaryFile(PLAT_SERVER_EXEC, "DDNet-Server.old");
-	Success &= m_pStorage->RenameBinaryFile("update/DDNet-Server.tmp", PLAT_SERVER_EXEC);
+	m_pStorage->RemoveBinaryFile(SERVER_EXEC ".old");
+	Success &= m_pStorage->RenameBinaryFile(PLAT_SERVER_EXEC, SERVER_EXEC ".old");
+	str_format(aPath, sizeof(aPath), "update/%s", m_aServerExecTmp);
+	Success &= m_pStorage->RenameBinaryFile(aPath, PLAT_SERVER_EXEC);
 	#if !defined(CONF_FAMILY_WINDOWS)
-		char aPath[512];
 		m_pStorage->GetBinaryPath(PLAT_SERVER_EXEC, aPath, sizeof aPath);
 		char aBuf[512];
 		str_format(aBuf, sizeof aBuf, "chmod +x %s", aPath);
 		if (system(aBuf))
 		{
 			dbg_msg("updater", "ERROR: failed to set server executable bit");
-			Success &= false;
+			Success = false;
 		}
 	#endif
 	return Success;
@@ -287,13 +293,13 @@ void CUpdater::PerformUpdate()
 	ParseUpdate();
 	m_State = DOWNLOADING;
 
-	const char *aLastFile;
-	aLastFile = "";
+	const char *pLastFile;
+	pLastFile = "";
 	for(map<string, bool>::reverse_iterator it = m_FileJobs.rbegin(); it != m_FileJobs.rend(); ++it)
 	{
 		if(it->second)
 		{
-			aLastFile = it->first.c_str();
+			pLastFile = it->first.c_str();
 			break;
 		}
 	}
@@ -319,7 +325,7 @@ void CUpdater::PerformUpdate()
 			{
 				FetchFile(pFile);
 			}
-			aLastFile = pFile;
+			pLastFile = pFile;
 		}
 		else
 			m_pStorage->RemoveBinaryFile(it->first.c_str());
@@ -327,16 +333,16 @@ void CUpdater::PerformUpdate()
 
 	if(m_ServerUpdate)
 	{
-		FetchFile(PLAT_SERVER_DOWN, "DDNet-Server.tmp");
-		aLastFile = "DDNet-Server.tmp";
+		FetchFile(PLAT_SERVER_DOWN, m_aServerExecTmp);
+		pLastFile = m_aServerExecTmp;
 	}
 	if(m_ClientUpdate)
 	{
-		FetchFile(PLAT_CLIENT_DOWN, "DDNet.tmp");
-		aLastFile = "DDNet.tmp";
+		FetchFile(PLAT_CLIENT_DOWN, m_aClientExecTmp);
+		pLastFile = m_aClientExecTmp;
 	}
 
-	str_copy(m_aLastFile, aLastFile, sizeof(m_aLastFile));
+	str_copy(m_aLastFile, pLastFile, sizeof(m_aLastFile));
 }
 
 void CUpdater::CommitUpdate()
@@ -371,7 +377,7 @@ void CUpdater::WinXpRestart()
 		if(!bhFile)
 			return;
 		char bBuf[512];
-		str_format(bBuf, sizeof(bBuf), ":_R\r\ndel \"DDNet.exe\"\r\nif exist \"DDNet.exe\" goto _R\r\n:_T\r\nmove /y \"update\\DDNet.tmp\" \"DDNet.exe\"\r\nif not exist \"DDNet.exe\" goto _T\r\nstart DDNet.exe\r\ndel \"du.bat\"\r\n");
+		str_format(bBuf, sizeof(bBuf), ":_R\r\ndel \"" PLAT_CLIENT_EXEC "\"\r\nif exist \"" PLAT_CLIENT_EXEC "\" goto _R\r\n:_T\r\nmove /y \"update\\%s\" \"" PLAT_CLIENT_EXEC "\"\r\nif not exist \"" PLAT_CLIENT_EXEC "\" goto _T\r\nstart " PLAT_CLIENT_EXEC "\r\ndel \"du.bat\"\r\n", m_aClientExecTmp);
 		io_write(bhFile, bBuf, str_length(bBuf));
 		io_close(bhFile);
 		shell_execute(aBuf);
