@@ -3,6 +3,8 @@
 #ifndef ENGINE_DEMO_H
 #define ENGINE_DEMO_H
 
+#include <base/hash.h>
+#include <engine/shared/uuid_manager.h>
 #include "kernel.h"
 
 enum
@@ -14,6 +16,14 @@ const double g_aSpeeds[] = {0.1, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5, 2.0, 3.0, 4.0,
 
 typedef bool (*DEMOFUNC_FILTER)(const void *pData, int DataSize, void *pUser);
 
+// TODO: Properly extend demo format using uuids
+static const CUuid SHA256_EXTENSION = {{
+	// "6be6da4a-cebd-380c-9b5b-1289c842d780"
+	// "demoitem-sha256@ddnet.tw"
+	0x6b, 0xe6, 0xda, 0x4a, 0xce, 0xbd, 0x38, 0x0c,
+	0x9b, 0x5b, 0x12, 0x89, 0xc8, 0x42, 0xd7, 0x80
+}};
+
 struct CDemoHeader
 {
 	unsigned char m_aMarker[7];
@@ -33,6 +43,14 @@ struct CTimelineMarkers
 	char m_aTimelineMarkers[MAX_TIMELINE_MARKERS][4];
 };
 
+struct CMapInfo
+{
+	char m_aName[128];
+	SHA256_DIGEST m_Sha256;
+	int m_Crc;
+	int m_Size;
+};
+
 class IDemoPlayer : public IInterface
 {
 	MACRO_INTERFACE("demoplayer", 0)
@@ -69,7 +87,7 @@ public:
 	virtual bool IsPlaying() const = 0;
 	virtual const CInfo *BaseInfo() const = 0;
 	virtual void GetDemoName(char *pBuffer, int BufferSize) const = 0;
-	virtual bool GetDemoInfo(class IStorage *pStorage, const char *pFilename, int StorageType, CDemoHeader *pDemoHeader, CTimelineMarkers *pTimelineMarkers) const = 0;
+	virtual bool GetDemoInfo(class IStorage *pStorage, const char *pFilename, int StorageType, CDemoHeader *pDemoHeader, CTimelineMarkers *pTimelineMarkers, CMapInfo *pMapInfo) const = 0;
 	virtual int GetDemoType() const = 0;
 };
 
