@@ -15,6 +15,8 @@ public:
 	virtual bool HasUnsavedData() = 0;
 	virtual int Load(const char *pFilename, int StorageType) = 0;
 	virtual int Save(const char *pFilename) = 0;
+	virtual void UpdateMentions() = 0;
+	virtual void ResetMentions() = 0;
 };
 
 extern IEditor *CreateEditor();
