@@ -1,9 +1,9 @@
 #ifndef ENGINE_SERVER_AUTHMANAGER_H
 #define ENGINE_SERVER_AUTHMANAGER_H
 
+#include <base/hash.h>
 #include <base/tl/array.h>
 
-#define MD5_BYTES 16
 #define SALT_BYTES 8
 
 class CAuthManager
@@ -19,7 +19,7 @@ private:
 	struct CKey
 	{
 		char m_aIdent[64];
-		unsigned char m_aPw[MD5_BYTES];
+		MD5_DIGEST m_Pw;
 		unsigned char m_aSalt[SALT_BYTES];
 		int m_Level;
 	};
@@ -33,7 +33,7 @@ public:
 	CAuthManager();
 
 	void Init();
-	int AddKeyHash(const char *pIdent, const unsigned char *pHash, const unsigned char *pSalt, int AuthLevel);
+	int AddKeyHash(const char *pIdent, MD5_DIGEST Hash, const unsigned char *pSalt, int AuthLevel);
 	int AddKey(const char *pIdent, const char *pPw, int AuthLevel);
 	int RemoveKey(int Slot); // Returns the old key slot that is now in the named one.
 	int FindKey(const char *pIdent);
@@ -41,7 +41,7 @@ public:
 	int DefaultKey(int AuthLevel);
 	int KeyLevel(int Slot);
 	const char *KeyIdent(int Slot);
-	void UpdateKeyHash(int Slot, const unsigned char *pHash, const unsigned char *pSalt, int AuthLevel);
+	void UpdateKeyHash(int Slot, MD5_DIGEST Hash, const unsigned char *pSalt, int AuthLevel);
 	void UpdateKey(int Slot, const char *pPw, int AuthLevel);
 	void ListKeys(FListCallback pfnListCallbac, void *pUser);
 	void AddDefaultKey(int Level, const char *pPw);
