@@ -65,7 +65,10 @@ public:
 		if(!m_pStorage || !g_Config.m_ClSaveSettings)
 			return;
 
-		m_ConfigFile = m_pStorage->OpenFile(CONFIG_FILE_TMP, IOFLAG_WRITE, IStorage::TYPE_SAVE);
+		char aConfigFileTmp[64];
+		str_format(aConfigFileTmp, sizeof(aConfigFileTmp), CONFIG_FILE ".%d.tmp", pid());
+
+		m_ConfigFile = m_pStorage->OpenFile(aConfigFileTmp, IOFLAG_WRITE, IStorage::TYPE_SAVE);
 
 		if(!m_ConfigFile)
 			return;
@@ -95,12 +98,12 @@ public:
 
 		if(m_Failed)
 		{
-			dbg_msg("config", "ERROR: writing to " CONFIG_FILE_TMP " failed");
+			dbg_msg("config", "ERROR: writing to %s failed", aConfigFileTmp);
 			return;
 		}
 
-		if(!m_pStorage->RenameFile(CONFIG_FILE_TMP, CONFIG_FILE, IStorage::TYPE_SAVE))
-			dbg_msg("config", "ERROR: renaming " CONFIG_FILE_TMP " to " CONFIG_FILE " failed");
+		if(!m_pStorage->RenameFile(aConfigFileTmp, CONFIG_FILE, IStorage::TYPE_SAVE))
+			dbg_msg("config", "ERROR: renaming %s to " CONFIG_FILE " failed", aConfigFileTmp);
 	}
 
 	virtual void RegisterCallback(SAVECALLBACKFUNC pfnFunc, void *pUserData)
