@@ -3,6 +3,8 @@
 #ifndef ENGINE_SHARED_DATAFILE_H
 #define ENGINE_SHARED_DATAFILE_H
 
+#include <engine/storage.h>
+
 #include <base/system.h>
 #include <base/hash.h>
 
@@ -95,8 +97,8 @@ public:
 	CDataFileWriter();
 	~CDataFileWriter();
 	void Init();
-	bool OpenFile(class IStorage *pStorage, const char *pFilename);
-	bool Open(class IStorage *pStorage, const char *Filename);
+	bool OpenFile(class IStorage *pStorage, const char *pFilename, int StorageType = IStorage::TYPE_SAVE);
+	bool Open(class IStorage *pStorage, const char *Filename, int StorageType = IStorage::TYPE_SAVE);
 	int AddData(int Size, void *pData);
 	int AddDataSwapped(int Size, void *pData);
 	int AddItem(int Type, int ID, int Size, void *pData);
