@@ -1,13 +1,13 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include <base/system.h>
+#include <base/hash_ctxt.h>
 
 #include <engine/console.h>
 
 #include "config.h"
 #include "netban.h"
 #include "network.h"
-#include <engine/external/md5/md5.h>
 #include <engine/message.h>
 #include <engine/shared/protocol.h>
 
@@ -71,7 +71,6 @@ bool CNetServer::Open(NETADDR BindAddr, CNetBan *pNetBan, int MaxClients, int Ma
 	m_NumConAttempts = 0;
 	m_TimeNumConAttempts = time_get();
 
-	m_VConnHighLoad = false;
 	m_VConnNum = 0;
 	m_VConnFirst = 0;
 
@@ -145,16 +144,12 @@ int CNetServer::Update()
 
 SECURITY_TOKEN CNetServer::GetToken(const NETADDR &Addr)
 {
-	md5_state_t md5;
-	md5_byte_t digest[16];
-	SECURITY_TOKEN SecurityToken;
-	md5_init(&md5);
+	SHA256_CTX Sha256;
+	sha256_init(&Sha256);
+	sha256_update(&Sha256, (unsigned char*)m_SecurityTokenSeed, sizeof(m_SecurityTokenSeed));
+	sha256_update(&Sha256, (unsigned char*)&Addr, sizeof(Addr));
 
-	md5_append(&md5, (unsigned char*)m_SecurityTokenSeed, sizeof(m_SecurityTokenSeed));
-	md5_append(&md5, (unsigned char*)&Addr, sizeof(Addr));
-
-	md5_finish(&md5, digest);
-	SecurityToken = ToSecurityToken(digest);
+	SECURITY_TOKEN SecurityToken = ToSecurityToken(sha256_finish(&Sha256).data);
 
 	if (SecurityToken == NET_SECURITY_TOKEN_UNKNOWN ||
 		SecurityToken == NET_SECURITY_TOKEN_UNSUPPORTED)
@@ -298,8 +293,8 @@ void CNetServer::SendMsgs(NETADDR &Addr, const CMsgPacker *Msgs[], int num)
 		Header.m_Sequence = i+1;
 		pChunkData = Header.Pack(pChunkData);
 		mem_copy(pChunkData, pMsg->Data(), pMsg->Size());
-		*((unsigned char*)pChunkData) <<= 1;
-		*((unsigned char*)pChunkData) |= 1;
+		*pChunkData <<= 1;
+		*pChunkData |= 1;
 		pChunkData += pMsg->Size();
 		m_Construct.m_NumChunks++;
 	}
@@ -341,20 +336,24 @@ void CNetServer::OnPreConnMsg(NETADDR &Addr, CNetPacketConstruct &Packet)
 	{
 		if (g_Config.m_SvVanillaAntiSpoof && g_Config.m_Password[0] == '\0')
 		{
-			// detect flooding
-			int64 Now = time_get();
-			if(Now <= m_VConnFirst + time_freq())
-			{
-				m_VConnNum++;
-			}
-			else
-			{
-				m_VConnHighLoad = m_VConnNum > g_Config.m_SvVanConnPerSecond;
-				m_VConnNum = 1;
-				m_VConnFirst = Now;
-			}
+			bool Flooding = false;
 
-			bool Flooding = m_VConnNum > g_Config.m_SvVanConnPerSecond || m_VConnHighLoad;
+			if (g_Config.m_SvVanConnPerSecond)
+			{
+				// detect flooding
+				Flooding = m_VConnNum > g_Config.m_SvVanConnPerSecond;
+				const int64 Now = time_get();
+
+				if(Now <= m_VConnFirst + time_freq())
+				{
+					m_VConnNum++;
+				}
+				else
+				{
+					m_VConnNum = 1;
+					m_VConnFirst = Now;
+				}
+			}
 
 			if (g_Config.m_Debug && Flooding)
 			{
@@ -421,8 +420,8 @@ void CNetServer::OnPreConnMsg(NETADDR &Addr, CNetPacketConstruct &Packet)
 
 			CMsgPacker SnapEmptyMsg(NETMSG_SNAPEMPTY);
 			SECURITY_TOKEN SecurityToken = GetVanillaToken(Addr);
-			SnapEmptyMsg.AddInt((int)SecurityToken);
-			SnapEmptyMsg.AddInt((int)SecurityToken + 1);
+			SnapEmptyMsg.AddInt(SecurityToken);
+			SnapEmptyMsg.AddInt(SecurityToken + 1);
 
 			// send all chunks/msgs in one packet
 			const CMsgPacker *Msgs[] = {&MapChangeMsg, &MapDataMsg, &ConReadyMsg,
