@@ -33,7 +33,8 @@ public:
 	{
 		OFFSET_UUID_TYPE=0x4000,
 		MAX_TYPE=0x7fff,
-		MAX_SIZE=64*1024
+		MAX_PARTS=64,
+		MAX_SIZE=MAX_PARTS*1024
 	};
 
 	void Clear() { m_DataSize = 0; m_NumItems = 0; }
