@@ -269,7 +269,7 @@ bool CChat::OnInput(IInput::CEvent Event)
 		{
 			bool AddEntry = false;
 
-			if(m_LastChatSend+time_freq() < time_get())
+			if(m_LastChatSend+time_freq() < time())
 			{
 				Say(m_Mode == MODE_ALL ? 0 : 1, m_Input.GetString());
 				AddEntry = true;
@@ -600,7 +600,7 @@ void CChat::AddLine(int ClientID, int Team, const char *pLine)
 		}
 
 		m_CurrentLine = (m_CurrentLine+1)%MAX_LINES;
-		m_aLines[m_CurrentLine].m_Time = time_get();
+		m_aLines[m_CurrentLine].m_Time = time();
 		m_aLines[m_CurrentLine].m_YOffset[0] = -1.0f;
 		m_aLines[m_CurrentLine].m_YOffset[1] = -1.0f;
 		m_aLines[m_CurrentLine].m_ClientID = ClientID;
@@ -684,8 +684,8 @@ void CChat::AddLine(int ClientID, int Team, const char *pLine)
 	}
 
 	// play sound
-	int64 Now = time_get();
-	if(ClientID == -1) // Server message
+	int64 Now = time();
+	if(ClientID == -1)
 	{
 		if(Now-m_aLastSoundPlayed[CHAT_SERVER] >= time_freq()*3/10)
 		{
@@ -748,7 +748,7 @@ void CChat::OnPrepareLines()
 	m_PrevScoreBoardShowed = m_pClient->m_pScoreboard->Active();
 	m_PrevShowChat = m_Show;
 
-	int64 Now = time_get();
+	int64 Now = time();
 	float LineWidth = m_pClient->m_pScoreboard->Active() ? 90.0f : 200.0f;
 	float HeightLimit = m_pClient->m_pScoreboard->Active() ? 230.0f : m_Show ? 50.0f : 200.0f;
 	float Begin = x;
@@ -810,7 +810,7 @@ void CChat::OnPrepareLines()
 		if(g_Config.m_ClMessageFriend)
 		{
 			ColorRGBA rgb = color_cast<ColorRGBA>(ColorHSLA(g_Config.m_ClMessageFriendColor));
-			TextRender()->TextColor(rgb.SetAlpha(m_aLines[r].m_Friend ? 1.f : 0.f)); //Less ugly hack to align messages
+			TextRender()->TextColor(rgb.WithAlpha(m_aLines[r].m_Friend ? 1.f : 0.f)); //Less ugly hack to align messages
 			m_aLines[r].m_TextContainerIndex = TextRender()->CreateTextContainer(&Cursor, "♥ ");
 		}
 
@@ -888,7 +888,7 @@ void CChat::OnPrepareLines()
 void CChat::OnRender()
 {
 	// send pending chat messages
-	if(m_PendingChatCounter > 0 && m_LastChatSend+time_freq() < time_get())
+	if(m_PendingChatCounter > 0 && m_LastChatSend+time_freq() < time())
 	{
 		CHistoryEntry *pEntry = m_History.Last();
 		for(int i = m_PendingChatCounter-1; pEntry; --i, pEntry = m_History.Prev(pEntry))
@@ -969,14 +969,18 @@ void CChat::OnRender()
 		TextRender()->TextEx(&Cursor, m_Input.GetString(Editing)+m_Input.GetCursorOffset(Editing), -1);
 	}
 
+#if defined(CONF_VIDEORECORDER)
+	if(!((g_Config.m_ClShowChat && !IVideo::Current()) || (g_Config.m_ClVideoShowChat && IVideo::Current())))
+#else
 	if(!g_Config.m_ClShowChat)
+#endif
 		return;
 
 	y -= 8.0f;
 
 	OnPrepareLines();
 
-	int64 Now = time_get();
+	int64 Now = time();
 	float HeightLimit = m_pClient->m_pScoreboard->Active() ? 230.0f : m_Show ? 50.0f : 200.0f;
 	int OffsetType = m_pClient->m_pScoreboard->Active() ? 1 : 0;
 	for(int i = 0; i < MAX_LINES; i++)
@@ -1004,7 +1008,7 @@ void CChat::OnRender()
 
 void CChat::Say(int Team, const char *pLine)
 {
-	m_LastChatSend = time_get();
+	m_LastChatSend = time();
 
 	// send chat message
 	CNetMsg_Cl_Say Msg;
@@ -1020,7 +1024,7 @@ void CChat::SayChat(const char *pLine)
 
 	bool AddEntry = false;
 
-	if(m_LastChatSend+time_freq() < time_get())
+	if(m_LastChatSend+time_freq() < time())
 	{
 		Say(m_Mode == MODE_ALL ? 0 : 1, pLine);
 		AddEntry = true;
