@@ -31,7 +31,7 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 	View.HSplitBottom(28.0f, &View, &Status);
 
 	// split of the scrollbar
-	RenderTools()->DrawUIRect(&Headers, vec4(1,1,1,0.25f), CUI::CORNER_T, 5.0f);
+	RenderTools()->DrawUIRect(&Headers, ColorRGBA(1,1,1,0.25f), CUI::CORNER_T, 5.0f);
 	Headers.VSplitRight(20.0f, &Headers, 0);
 
 	struct CColumn
@@ -53,6 +53,7 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 
 		COL_FLAG_LOCK=0,
 		COL_FLAG_FAV,
+		COL_FLAG_OFFICIAL,
 		COL_NAME,
 		COL_GAMETYPE,
 		COL_MAP,
@@ -65,15 +66,13 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 		{-1,			-1,						" ",		-1, 2.0f, 0, {0}, {0}},
 		{COL_FLAG_LOCK,	-1,						" ",		-1, 14.0f, 0, {0}, {0}},
 		{COL_FLAG_FAV,	-1,						" ",		-1, 14.0f, 0, {0}, {0}},
+		{COL_FLAG_OFFICIAL,	-1,						" ",		-1, 14.0f, 0, {0}, {0}},
 		{COL_NAME,		IServerBrowser::SORT_NAME,		"Name",		0, 50.0f, 0, {0}, {0}},	// Localize - these strings are localized within CLocConstString
 		{COL_GAMETYPE,	IServerBrowser::SORT_GAMETYPE,	"Type",		1, 50.0f, 0, {0}, {0}},
 		{COL_MAP,		IServerBrowser::SORT_MAP,			"Map", 		1, 120.0f + (Headers.w - 480) / 8, 0, {0}, {0}},
 		{COL_PLAYERS,	IServerBrowser::SORT_NUMPLAYERS,	"Players",	1, 60.0f, 0, {0}, {0}},
 		{-1,			-1,						" ",		1, 10.0f, 0, {0}, {0}},
 		{COL_PING,		IServerBrowser::SORT_PING,		"Ping",		1, 40.0f, FIXED, {0}, {0}},
-#if defined(__ANDROID__)
-		{-1,			-1,						" ",		1, 50.0f, 0, {0}, {0}}, // Scrollbar
-#endif
 	};
 	// This is just for scripts/update_localization.py to work correctly (all other strings are already Localize()'d somewhere else). Don't remove!
 	// Localize("Type");
@@ -126,14 +125,10 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 		}
 	}
 
-	RenderTools()->DrawUIRect(&View, vec4(0,0,0,0.15f), 0, 0);
+	RenderTools()->DrawUIRect(&View, ColorRGBA(0,0,0,0.15f), 0, 0);
 
 	CUIRect Scroll;
-#if defined(__ANDROID__)
-	View.VSplitRight(50, &View, &Scroll);
-#else
 	View.VSplitRight(15, &View, &Scroll);
-#endif
 
 	int NumServers = ServerBrowser()->NumSortedServers();
 
@@ -189,8 +184,8 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 			{
 				if(m_aInputEvents[i].m_Key == KEY_DOWN) NewIndex = m_SelectedIndex + 1;
 				else if(m_aInputEvents[i].m_Key == KEY_UP) NewIndex = m_SelectedIndex - 1;
-				else if(m_aInputEvents[i].m_Key == KEY_PAGEUP) NewIndex = max(m_SelectedIndex - 25, 0);
-				else if(m_aInputEvents[i].m_Key == KEY_PAGEDOWN) NewIndex = min(m_SelectedIndex + 25, NumServers - 1);
+				else if(m_aInputEvents[i].m_Key == KEY_PAGEUP) NewIndex = maximum(m_SelectedIndex - 25, 0);
+				else if(m_aInputEvents[i].m_Key == KEY_PAGEDOWN) NewIndex = minimum(m_SelectedIndex + 25, NumServers - 1);
 				else if(m_aInputEvents[i].m_Key == KEY_HOME) NewIndex = 0;
 				else if(m_aInputEvents[i].m_Key == KEY_END) NewIndex = NumServers - 1;
 			}
@@ -285,7 +280,7 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 			{
 				CUIRect r = Row;
 				r.Margin(0.5f, &r);
-				RenderTools()->DrawUIRect(&r, vec4(1,1,1,0.5f), CUI::CORNER_ALL, 4.0f);
+				RenderTools()->DrawUIRect(&r, ColorRGBA(1,1,1,0.5f), CUI::CORNER_ALL, 4.0f);
 			}
 
 			// clip the selection
@@ -336,6 +331,11 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 				if(pItem->m_Favorite)
 					DoButton_Icon(IMAGE_BROWSEICONS, SPRITE_BROWSE_HEART, &Button);
 			}
+			else if(ID == COL_FLAG_OFFICIAL)
+			{
+				if(pItem->m_Official && g_Config.m_UiPage != PAGE_DDNET && g_Config.m_UiPage != PAGE_KOG)
+					DoButton_Icon(IMAGE_BROWSEICONS, SPRITE_BROWSE_DDNET, &Button);
+			}
 			else if(ID == COL_NAME)
 			{
 				CTextCursor Cursor;
@@ -418,8 +418,8 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 				str_format(aTemp, sizeof(aTemp), "%i", pItem->m_Latency);
 				if(g_Config.m_UiColorizePing)
 				{
-					vec3 rgb = HslToRgb(vec3((300.0f - clamp(pItem->m_Latency, 0, 300)) / 1000.0f, 1.0f, 0.5f));
-					TextRender()->TextColor(rgb.r, rgb.g, rgb.b, 1.0f);
+					ColorRGBA rgb = color_cast<ColorRGBA>(ColorHSLA((300.0f - clamp(pItem->m_Latency, 0, 300)) / 1000.0f, 1.0f, 0.5f));
+					TextRender()->TextColor(rgb);
 				}
 
 				UI()->DoLabelScaled(&Button, aTemp, 12.0f, 1);
@@ -439,25 +439,25 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 
 				if(g_Config.m_UiColorizeGametype)
 				{
-					vec3 hsl = vec3(1.0f, 1.0f, 1.0f);
+					ColorHSLA hsl = ColorHSLA(1.0f, 1.0f, 1.0f);
 
 					if(IsVanilla(pItem))
-						hsl = vec3(0.33f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.33f, 1.0f, 0.75f);
 					else if(IsCatch(pItem))
-						hsl = vec3(0.17f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.17f, 1.0f, 0.75f);
 					else if(IsInsta(pItem))
-						hsl = vec3(0.00f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.00f, 1.0f, 0.75f);
 					else if(IsFNG(pItem))
-						hsl = vec3(0.83f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.83f, 1.0f, 0.75f);
 					else if(IsDDNet(pItem))
-						hsl = vec3(0.58f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.58f, 1.0f, 0.75f);
 					else if(IsDDRace(pItem))
-						hsl = vec3(0.75f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.75f, 1.0f, 0.75f);
 					else if(IsRace(pItem))
-						hsl = vec3(0.46f, 1.0f, 0.75f);
+						hsl = ColorHSLA(0.46f, 1.0f, 0.75f);
 
-					vec3 rgb = HslToRgb(hsl);
-					TextRender()->TextColor(rgb.r, rgb.g, rgb.b, 1.0f);
+					ColorRGBA rgb = color_cast<ColorRGBA>(hsl);
+					TextRender()->TextColor(rgb);
 					TextRender()->TextEx(&Cursor, pItem->m_aGameType, -1);
 					TextRender()->TextColor(1.0f, 1.0f, 1.0f, 1.0f);
 				}
@@ -474,15 +474,11 @@ void CMenus::RenderServerbrowserServerList(CUIRect View)
 		// select the new server
 		const CServerInfo *pItem = ServerBrowser()->SortedGet(NewSelected);
 		str_copy(g_Config.m_UiServerAddress, pItem->m_aAddress, sizeof(g_Config.m_UiServerAddress));
-#if defined(__ANDROID__)
-		if(DoubleClicked)
-#else
 		if(Input()->MouseDoubleClick() && DoubleClicked)
-#endif
 			Client()->Connect(g_Config.m_UiServerAddress);
 	}
 
-	RenderTools()->DrawUIRect(&Status, vec4(1,1,1,0.25f), CUI::CORNER_B, 5.0f);
+	RenderTools()->DrawUIRect(&Status, ColorRGBA(1,1,1,0.25f), CUI::CORNER_B, 5.0f);
 	Status.Margin(5.0f, &Status);
 
 	CUIRect QuickSearch, QuickExclude, Button, Status2, Status3;
@@ -544,8 +540,8 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 
 	// server filter
 	ServerFilter.HSplitTop(ms_ListheaderHeight, &FilterHeader, &ServerFilter);
-	RenderTools()->DrawUIRect(&FilterHeader, vec4(1,1,1,0.25f), CUI::CORNER_T, 4.0f);
-	RenderTools()->DrawUIRect(&ServerFilter, vec4(0,0,0,0.15f), CUI::CORNER_B, 4.0f);
+	RenderTools()->DrawUIRect(&FilterHeader, ColorRGBA(1,1,1,0.25f), CUI::CORNER_T, 4.0f);
+	RenderTools()->DrawUIRect(&ServerFilter, ColorRGBA(0,0,0,0.15f), CUI::CORNER_B, 4.0f);
 	UI()->DoLabelScaled(&FilterHeader, Localize("Server filter"), FontSize+2.0f, 0);
 	CUIRect Button, Button2;
 
@@ -635,7 +631,7 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 		float OldWidth = Rect.w;
 		Rect.w = Rect.h*2;
 		Rect.x += (OldWidth-Rect.w)/2.0f;
-		vec4 Color(1.0f, 1.0f, 1.0f, g_Config.m_BrFilterCountry?1.0f: 0.5f);
+		ColorRGBA Color(1.0f, 1.0f, 1.0f, g_Config.m_BrFilterCountry?1.0f: 0.5f);
 		m_pClient->m_pCountryFlags->Render(g_Config.m_BrFilterCountryIndex, &Color, Rect.x, Rect.y, Rect.w, Rect.h);
 
 		if(g_Config.m_BrFilterCountry && UI()->DoButtonLogic(&g_Config.m_BrFilterCountryIndex, "", 0, &Rect))
@@ -668,7 +664,11 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 		{
 			g_Config.m_BrFilterUnfinishedMap = 0;
 		}
+	}
 
+	if(g_Config.m_UiPage == PAGE_DDNET || g_Config.m_UiPage == PAGE_KOG)
+	{
+		int Network = g_Config.m_UiPage == PAGE_DDNET ? IServerBrowser::NETWORK_DDNET : IServerBrowser::NETWORK_KOG;
 		// add more space
 		ServerFilter.HSplitTop(10.0f, 0, &ServerFilter);
 		ServerFilter.HSplitTop(20.0f, &Button, &ServerFilter);
@@ -694,8 +694,9 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 
 		if(s_ActivePage == 1)
 		{
-			int MaxTypes = ServerBrowser()->NumDDNetTypes();
-			int NumTypes = ServerBrowser()->NumDDNetTypes();
+			char *pFilterExcludeTypes = Network == IServerBrowser::NETWORK_DDNET ? g_Config.m_BrFilterExcludeTypes : g_Config.m_BrFilterExcludeTypesKoG;
+			int MaxTypes = ServerBrowser()->NumTypes(Network);
+			int NumTypes = ServerBrowser()->NumTypes(Network);
 			int PerLine = 3;
 
 			ServerFilter.HSplitTop(4.0f, 0, &ServerFilter);
@@ -716,8 +717,8 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 				for(int i = 0; i < PerLine && NumTypes > 0; i++, NumTypes--)
 				{
 					int TypeIndex = MaxTypes - NumTypes;
-					const char *pName = ServerBrowser()->GetDDNetType(TypeIndex);
-					bool Active = !ServerBrowser()->DDNetFiltered(g_Config.m_BrFilterExcludeTypes, pName);
+					const char *pName = ServerBrowser()->GetType(Network, TypeIndex);
+					bool Active = !ServerBrowser()->DDNetFiltered(pFilterExcludeTypes, pName);
 
 					vec2 Pos = vec2(TypesRect.x+TypesRect.w*((i+0.5f)/(float)PerLine), TypesRect.y);
 
@@ -737,35 +738,31 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 					{
 						// left click to toggle flag filter
 						if(Active)
-							ServerBrowser()->DDNetFilterAdd(g_Config.m_BrFilterExcludeTypes, pName);
+							ServerBrowser()->DDNetFilterAdd(pFilterExcludeTypes, pName);
 						else
-							ServerBrowser()->DDNetFilterRem(g_Config.m_BrFilterExcludeTypes, pName);
+							ServerBrowser()->DDNetFilterRem(pFilterExcludeTypes, pName);
 
-						ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
+						ServerBrowser()->Refresh(ServerBrowser()->GetCurrentType());
 					}
 					else if(Button == 2)
 					{
 						// right click to exclusively activate one
-						g_Config.m_BrFilterExcludeTypes[0] = '\0';
+						pFilterExcludeTypes[0] = '\0';
 						for(int j = 0; j < MaxTypes; ++j)
 						{
 							if(j != TypeIndex)
-								ServerBrowser()->DDNetFilterAdd(g_Config.m_BrFilterExcludeTypes, ServerBrowser()->GetDDNetType(j));
+								ServerBrowser()->DDNetFilterAdd(pFilterExcludeTypes, ServerBrowser()->GetType(Network, j));
 						}
-						ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
+						ServerBrowser()->Refresh(ServerBrowser()->GetCurrentType());
 					}
 					else if(Button == 3)
 					{
 						// middle click to reset (re-enable all)
-						g_Config.m_BrFilterExcludeTypes[0] = '\0';
-						ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
+						pFilterExcludeTypes[0] = '\0';
+						ServerBrowser()->Refresh(ServerBrowser()->GetCurrentType());
 					}
 
-					vec4 Color(1.0f, 1.0f, 1.0f, 1.0f);
-
-					if(!Active)
-						Color.a = 0.2f;
-					TextRender()->TextColor(Color.r, Color.g, Color.b, Color.a);
+					TextRender()->TextColor(1.0f, 1.0f, 1.0f, Active ? 1.0f : 0.2f);
 					UI()->DoLabelScaled(&Rect, pName, FontSize, 0);
 					TextRender()->TextColor(1.0, 1.0, 1.0, 1.0f);
 				}
@@ -773,15 +770,14 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 		}
 		else
 		{
+			char *pFilterExcludeCountries = Network == IServerBrowser::NETWORK_DDNET ? g_Config.m_BrFilterExcludeCountries : g_Config.m_BrFilterExcludeCountriesKoG;
 			ServerFilter.HSplitTop(17.0f, &ServerFilter, &ServerFilter);
 
-			vec4 Color(1.0f, 1.0f, 1.0f, 1.0f);
-
 			const float FlagWidth = 40.0f;
 			const float FlagHeight = 20.0f;
 
-			int MaxFlags = ServerBrowser()->NumDDNetCountries();
-			int NumFlags = ServerBrowser()->NumDDNetCountries();
+			int MaxFlags = ServerBrowser()->NumCountries(Network);
+			int NumFlags = ServerBrowser()->NumCountries(Network);
 			int PerLine = MaxFlags > 9 ? 4 : 3;
 
 			CUIRect FlagsRect;
@@ -795,9 +791,9 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 				for(int i = 0; i < PerLine && NumFlags > 0; i++, NumFlags--)
 				{
 					int CountryIndex = MaxFlags - NumFlags;
-					const char *pName = ServerBrowser()->GetDDNetCountryName(CountryIndex);
-					bool Active = !ServerBrowser()->DDNetFiltered(g_Config.m_BrFilterExcludeCountries, pName);
-					int FlagID = ServerBrowser()->GetDDNetCountryFlag(CountryIndex);
+					const char *pName = ServerBrowser()->GetCountryName(Network, CountryIndex);
+					bool Active = !ServerBrowser()->DDNetFiltered(pFilterExcludeCountries, pName);
+					int FlagID = ServerBrowser()->GetCountryFlag(Network, CountryIndex);
 
 					vec2 Pos = vec2(FlagsRect.x+FlagsRect.w*((i+0.5f)/(float)PerLine), FlagsRect.y);
 
@@ -818,35 +814,31 @@ void CMenus::RenderServerbrowserFilters(CUIRect View)
 					{
 						// left click to toggle flag filter
 						if(Active)
-							ServerBrowser()->DDNetFilterAdd(g_Config.m_BrFilterExcludeCountries, pName);
+							ServerBrowser()->DDNetFilterAdd(pFilterExcludeCountries, pName);
 						else
-							ServerBrowser()->DDNetFilterRem(g_Config.m_BrFilterExcludeCountries, pName);
+							ServerBrowser()->DDNetFilterRem(pFilterExcludeCountries, pName);
 
-						ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
+						ServerBrowser()->Refresh(ServerBrowser()->GetCurrentType());
 					}
 					else if(Button == 2)
 					{
 						// right click to exclusively activate one
-						g_Config.m_BrFilterExcludeCountries[0] = '\0';
+						pFilterExcludeCountries[0] = '\0';
 						for(int j = 0; j < MaxFlags; ++j)
 						{
 							if(j != CountryIndex)
-								ServerBrowser()->DDNetFilterAdd(g_Config.m_BrFilterExcludeCountries, ServerBrowser()->GetDDNetCountryName(j));
+								ServerBrowser()->DDNetFilterAdd(pFilterExcludeCountries, ServerBrowser()->GetCountryName(Network, j));
 						}
-						ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
+						ServerBrowser()->Refresh(ServerBrowser()->GetCurrentType());
 					}
 					else if(Button == 3)
 					{
 						// middle click to reset (re-enable all)
-						g_Config.m_BrFilterExcludeCountries[0] = '\0';
-						ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
+						pFilterExcludeCountries[0] = '\0';
+						ServerBrowser()->Refresh(ServerBrowser()->GetCurrentType());
 					}
 
-					vec4 Color(1.0f, 1.0f, 1.0f, 1.0f);
-
-					if(!Active)
-						Color.a = 0.2f;
-
+					ColorRGBA Color(1.0f, 1.0f, 1.0f, Active ? 1.0f : 0.2f);
 					m_pClient->m_pCountryFlags->Render(FlagID, &Color, Pos.x, Pos.y, FlagWidth, FlagHeight);
 				}
 			}
@@ -895,8 +887,8 @@ void CMenus::RenderServerbrowserServerDetail(CUIRect View)
 	CTextCursor Cursor;
 	const float FontSize = 12.0f;
 	ServerDetails.HSplitTop(ms_ListheaderHeight, &ServerHeader, &ServerDetails);
-	RenderTools()->DrawUIRect(&ServerHeader, vec4(1,1,1,0.25f), CUI::CORNER_T, 4.0f);
-	RenderTools()->DrawUIRect(&ServerDetails, vec4(0,0,0,0.15f), CUI::CORNER_B, 4.0f);
+	RenderTools()->DrawUIRect(&ServerHeader, ColorRGBA(1,1,1,0.25f), CUI::CORNER_T, 4.0f);
+	RenderTools()->DrawUIRect(&ServerDetails, ColorRGBA(0,0,0,0.15f), CUI::CORNER_B, 4.0f);
 	UI()->DoLabelScaled(&ServerHeader, Localize("Server details"), FontSize+2.0f, 0);
 
 	if(pSelectedServer)
@@ -984,9 +976,10 @@ void CMenus::RenderServerbrowserServerDetail(CUIRect View)
 				Client()->ServerBrowserUpdate();
 			}
 
-			vec4 Colour = pSelectedServer->m_aClients[i].m_FriendState == IFriends::FRIEND_NO ? vec4(1.0f, 1.0f, 1.0f, (i%2+1)*0.05f) :
-																								vec4(0.5f, 1.0f, 0.5f, 0.15f+(i%2+1)*0.05f);
-			RenderTools()->DrawUIRect(&Name, Colour, CUI::CORNER_ALL, 4.0f);
+			ColorRGBA Color = pSelectedServer->m_aClients[i].m_FriendState == IFriends::FRIEND_NO ?
+				ColorRGBA(1.0f, 1.0f, 1.0f, (i%2+1)*0.05f) :
+				ColorRGBA(0.5f, 1.0f, 0.5f, 0.15f+(i%2+1)*0.05f);
+			RenderTools()->DrawUIRect(&Name, Color, CUI::CORNER_ALL, 4.0f);
 			Name.VSplitLeft(5.0f, 0, &Name);
 			Name.VSplitLeft(34.0f, &Score, &Name);
 			Name.VSplitRight(34.0f, &Name, &Flag);
@@ -998,10 +991,12 @@ void CMenus::RenderServerbrowserServerDetail(CUIRect View)
 
 			if(!pSelectedServer->m_aClients[i].m_Player)
 				str_copy(aTemp, "SPEC", sizeof(aTemp));
-			else if(IsRace(pSelectedServer))
+			else if(IsRace(pSelectedServer) && g_Config.m_ClDDRaceScoreBoard)
 			{
 				if(pSelectedServer->m_aClients[i].m_Score == -9999 || pSelectedServer->m_aClients[i].m_Score == 0)
+				{
 					aTemp[0] = 0;
+				}
 				else
 				{
 					int Time = abs(pSelectedServer->m_aClients[i].m_Score);
@@ -1060,8 +1055,8 @@ void CMenus::RenderServerbrowserServerDetail(CUIRect View)
 				TextRender()->TextEx(&Cursor, pClan, -1);
 
 			// flag
-			vec4 Color(1.0f, 1.0f, 1.0f, 0.5f);
-			m_pClient->m_pCountryFlags->Render(pSelectedServer->m_aClients[i].m_Country, &Color, Flag.x, Flag.y, Flag.w, Flag.h);
+			ColorRGBA FColor(1.0f, 1.0f, 1.0f, 0.5f);
+			m_pClient->m_pCountryFlags->Render(pSelectedServer->m_aClients[i].m_Country, &FColor, Flag.x, Flag.y, Flag.w, Flag.h);
 		}
 
 		UiDoListboxEnd(&s_ScrollValue, 0);
@@ -1095,8 +1090,8 @@ void CMenus::RenderServerbrowserFriends(CUIRect View)
 
 	// header
 	ServerFriends.HSplitTop(ms_ListheaderHeight, &FilterHeader, &ServerFriends);
-	RenderTools()->DrawUIRect(&FilterHeader, vec4(1,1,1,0.25f), CUI::CORNER_T, 4.0f);
-	RenderTools()->DrawUIRect(&ServerFriends, vec4(0,0,0,0.15f), 0, 4.0f);
+	RenderTools()->DrawUIRect(&FilterHeader, ColorRGBA(1,1,1,0.25f), CUI::CORNER_T, 4.0f);
+	RenderTools()->DrawUIRect(&ServerFriends, ColorRGBA(0,0,0,0.15f), 0, 4.0f);
 	UI()->DoLabelScaled(&FilterHeader, Localize("Friends"), FontSize+4.0f, 0);
 	CUIRect Button, List;
 
@@ -1108,11 +1103,7 @@ void CMenus::RenderServerbrowserFriends(CUIRect View)
 	static float s_ScrollValue = 0;
 	if(m_FriendlistSelectedIndex >= m_lFriends.size())
 		m_FriendlistSelectedIndex = m_lFriends.size()-1;
-#if defined(__ANDROID__)
-	UiDoListboxStart(&m_lFriends, &List, 50.0f, "", "", m_lFriends.size(), 1, m_FriendlistSelectedIndex, s_ScrollValue);
-#else
 	UiDoListboxStart(&m_lFriends, &List, 30.0f, "", "", m_lFriends.size(), 1, m_FriendlistSelectedIndex, s_ScrollValue);
-#endif
 
 	m_lFriends.sort_range();
 	for(int i = 0; i < m_lFriends.size(); ++i)
@@ -1124,14 +1115,14 @@ void CMenus::RenderServerbrowserFriends(CUIRect View)
 			Item.m_Rect.Margin(1.5f, &Item.m_Rect);
 			CUIRect OnState;
 			Item.m_Rect.VSplitRight(30.0f, &Item.m_Rect, &OnState);
-			RenderTools()->DrawUIRect(&Item.m_Rect, vec4(1.0f, 1.0f, 1.0f, 0.1f), CUI::CORNER_L, 4.0f);
+			RenderTools()->DrawUIRect(&Item.m_Rect, ColorRGBA(1.0f, 1.0f, 1.0f, 0.1f), CUI::CORNER_L, 4.0f);
 
 			Item.m_Rect.VMargin(2.5f, &Item.m_Rect);
 			Item.m_Rect.HSplitTop(12.0f, &Item.m_Rect, &Button);
 			UI()->DoLabelScaled(&Item.m_Rect, m_lFriends[i].m_pFriendInfo->m_aName, FontSize, -1);
 			UI()->DoLabelScaled(&Button, m_lFriends[i].m_pFriendInfo->m_aClan, FontSize, -1);
 
-			RenderTools()->DrawUIRect(&OnState, m_lFriends[i].m_NumFound ? vec4(0.0f, 1.0f, 0.0f, 0.25f) : vec4(1.0f, 0.0f, 0.0f, 0.25f), CUI::CORNER_R, 4.0f);
+			RenderTools()->DrawUIRect(&OnState, m_lFriends[i].m_NumFound ? ColorRGBA(0.0f, 1.0f, 0.0f, 0.25f) : ColorRGBA(1.0f, 0.0f, 0.0f, 0.25f), CUI::CORNER_R, 4.0f);
 			OnState.HMargin((OnState.h-FontSize)/3, &OnState);
 			OnState.VMargin(5.0f, &OnState);
 			char aBuf[64];
@@ -1230,7 +1221,7 @@ void CMenus::RenderServerbrowser(CUIRect MainView)
 	CUIRect ServerList, ToolBox, StatusBox, TabBar;
 
 	// background
-	RenderTools()->DrawUIRect(&MainView, ms_ColorTabbarActive, CUI::CORNER_ALL, 10.0f);
+	RenderTools()->DrawUIRect(&MainView, ms_ColorTabbarActive, CUI::CORNER_B, 10.0f);
 	MainView.Margin(10.0f, &MainView);
 
 	// create server list, status box, tab bar and tool box area
@@ -1255,10 +1246,10 @@ void CMenus::RenderServerbrowser(CUIRect MainView)
 		TabBar.HSplitTop(20.0f, &TabButton1, &TabBar);
 		TabBar.HSplitTop(2.5f, 0, &TabBar);
 		TabBar.HSplitTop(20.0f, &TabButton2, 0);
-		vec4 Active = ms_ColorTabbarActive;
-		vec4 InActive = ms_ColorTabbarInactive;
-		ms_ColorTabbarActive = vec4(0.0f, 0.0f, 0.0f, 0.3f);
-		ms_ColorTabbarInactive = vec4(0.0f, 0.0f, 0.0f, 0.15f);
+		ColorRGBA Active = ms_ColorTabbarActive;
+		ColorRGBA InActive = ms_ColorTabbarInactive;
+		ms_ColorTabbarActive = ColorRGBA(0.0f, 0.0f, 0.0f, 0.3f);
+		ms_ColorTabbarInactive = ColorRGBA(0.0f, 0.0f, 0.0f, 0.15f);
 
 		static int s_FiltersTab = 0;
 		if(DoButton_MenuTab(&s_FiltersTab, Localize("Filter"), ToolboxPage==0, &TabButton0, CUI::CORNER_L))
@@ -1279,7 +1270,7 @@ void CMenus::RenderServerbrowser(CUIRect MainView)
 
 	// tool box
 	{
-		RenderTools()->DrawUIRect(&ToolBox, vec4(0.0f, 0.0f, 0.0f, 0.15f), CUI::CORNER_T, 4.0f);
+		RenderTools()->DrawUIRect(&ToolBox, ColorRGBA(0.0f, 0.0f, 0.0f, 0.15f), CUI::CORNER_T, 4.0f);
 
 
 		if(ToolboxPage == 0)
@@ -1304,7 +1295,7 @@ void CMenus::RenderServerbrowser(CUIRect MainView)
 		bool NeedUpdate = str_comp(Client()->LatestVersion(), "0");
 		if(State == IUpdater::CLEAN && NeedUpdate)
 		{
-			str_format(aBuf, sizeof(aBuf), "DDNet %s is out!", Client()->LatestVersion());
+			str_format(aBuf, sizeof(aBuf), Localize("DDNet %s is out!"), Client()->LatestVersion());
 			TextRender()->TextColor(1.0f, 0.4f, 0.4f, 1.0f);
 		}
 		else if(State == IUpdater::CLEAN)
@@ -1315,16 +1306,16 @@ void CMenus::RenderServerbrowser(CUIRect MainView)
 		{
 			char aCurrentFile[64];
 			Updater()->GetCurrentFile(aCurrentFile, sizeof(aCurrentFile));
-			str_format(aBuf, sizeof(aBuf), "Downloading %s:", aCurrentFile);
+			str_format(aBuf, sizeof(aBuf), Localize("Downloading %s:"), aCurrentFile);
 		}
 		else if(State == IUpdater::FAIL)
 		{
-			str_format(aBuf, sizeof(aBuf), "Failed to download a file! Restart client to retry...");
+			str_format(aBuf, sizeof(aBuf), Localize("Update failed! Check log..."));
 			TextRender()->TextColor(1.0f, 0.4f, 0.4f, 1.0f);
 		}
 		else if(State == IUpdater::NEED_RESTART)
 		{
-			str_format(aBuf, sizeof(aBuf), "DDNet Client updated!");
+			str_format(aBuf, sizeof(aBuf), Localize("DDNet Client updated!"));
 			TextRender()->TextColor(1.0f, 0.4f, 0.4f, 1.0f);
 		}
 		UI()->DoLabelScaled(&Button, aBuf, 14.0f, -1);
@@ -1404,6 +1395,12 @@ void CMenus::RenderServerbrowser(CUIRect MainView)
 				Client()->RequestDDNetInfo();
 				ServerBrowser()->Refresh(IServerBrowser::TYPE_DDNET);
 			}
+			else if(g_Config.m_UiPage == PAGE_KOG)
+			{
+				// start a new serverlist request
+				Client()->RequestDDNetInfo();
+				ServerBrowser()->Refresh(IServerBrowser::TYPE_KOG);
+			}
 			m_DoubleClickIndex = -1;
 		}
 
