@@ -282,7 +282,7 @@ public:
 		bool m_EndlessJump;
 		bool m_NoHammerHit;
 		bool m_NoGrenadeHit;
-		bool m_NoRifleHit;
+		bool m_NoLaserHit;
 		bool m_NoShotgunHit;
 		bool m_NoHookHit;
 		bool m_Super;
@@ -310,6 +310,9 @@ public:
 		bool m_Paused;
 		bool m_Spec;
 
+		CNetObj_Character m_Snapped;
+		CNetObj_Character m_Evolved;
+
 		void UpdateRenderInfo();
 		void Reset();
 
