@@ -85,7 +85,7 @@ public:
 		DISABLE_HIT_HAMMER=1,
 		DISABLE_HIT_SHOTGUN=2,
 		DISABLE_HIT_GRENADE=4,
-		DISABLE_HIT_RIFLE=8
+		DISABLE_HIT_LASER=8
 	};
 	int m_Hit;
 	int m_TuneZone;
