@@ -25,6 +25,7 @@ public:
 	};
 
 	CWorldCore m_Core;
+	CTeamsCore m_Teams;
 
 	CGameWorld();
 	~CGameWorld();
@@ -47,13 +48,12 @@ public:
 	int m_GameTick;
 	int m_GameTickSpeed;
 	CCollision *m_pCollision;
-	CTeamsCore *m_pTeams;
 
 	// getter for server variables
 	int GameTick() { return m_GameTick; }
 	int GameTickSpeed() { return m_GameTickSpeed; }
 	class CCollision *Collision() { return m_pCollision; }
-	CTeamsCore *Teams() { return m_pTeams; }
+	CTeamsCore *Teams() { return &m_Teams; }
 	CTuningParams *Tuning();
 	CEntity *GetEntity(int ID, int EntityType);
 	class CCharacter *GetCharacterByID(int ID) { return (ID >= 0 && ID < MAX_CLIENTS) ? m_apCharacters[ID] : 0; }
@@ -88,6 +88,11 @@ public:
 	CEntity *FindMatch(int ObjID, int ObjType, const void *pObjData);
 	void Clear();
 
+	CTuningParams m_Tuning[2];
+	CTuningParams *m_pTuningList;
+	CTuningParams *TuningList() { return m_pTuningList; }
+	CTuningParams *GetTuning(int i) { return i == 0 ? Tuning() : &TuningList()[i]; }
+
 private:
 	void RemoveEntities();
 
