@@ -4,8 +4,7 @@ bool IsValidGameTile(int Index)
 {
 	return (
 		    Index == TILE_AIR
-		|| (Index >= TILE_SOLID && Index <= TILE_NOLASER)
-		||  Index == TILE_THROUGH
+		|| (Index >= TILE_SOLID && Index <= TILE_THROUGH)
 		||  Index == TILE_FREEZE
 		|| (Index >= TILE_UNFREEZE && Index <= TILE_DUNFREEZE)
 		|| (Index >= TILE_WALLJUMP && Index <= TILE_SOLO_END)
@@ -81,6 +80,11 @@ bool IsValidSwitchTile(int Index)
 	);
 }
 
+bool IsValidTuneTile(int Index)
+{
+	return Index == TILE_TUNE1;
+}
+
 bool IsValidEntity(int Index)
 {
 	Index -= ENTITY_OFFSET;
@@ -91,3 +95,18 @@ bool IsValidEntity(int Index)
 		||  Index == ENTITY_DOOR
 	);
 }
+
+bool IsRotatableTile(int Index)
+{
+	return (
+		    Index == TILE_STOP
+		||  Index == TILE_STOPS
+		||  Index == TILE_CP
+		||  Index == TILE_CP_F
+		||  Index == TILE_THROUGH_DIR
+		||  Index == TILE_ENTITIES_OFF_1
+		||  Index == TILE_ENTITIES_OFF_2
+		||  Index - ENTITY_OFFSET == ENTITY_CRAZY_SHOTGUN_EX
+		||  Index - ENTITY_OFFSET == ENTITY_CRAZY_SHOTGUN
+	);
+}
