@@ -3,6 +3,7 @@
 #include <engine/shared/config.h>
 #include <game/server/teams.h>
 #include <game/server/gamemodes/DDRace.h>
+#include <game/server/save.h>
 #include <game/version.h>
 #if defined(CONF_SQL)
 #include <game/server/score/sql_score.h>
@@ -160,10 +161,10 @@ void CGameContext::ConGrenade(IConsole::IResult *pResult, void *pUserData)
 	pSelf->ModifyWeapons(pResult, pUserData, WEAPON_GRENADE, false);
 }
 
-void CGameContext::ConRifle(IConsole::IResult *pResult, void *pUserData)
+void CGameContext::ConLaser(IConsole::IResult *pResult, void *pUserData)
 {
 	CGameContext *pSelf = (CGameContext *) pUserData;
-	pSelf->ModifyWeapons(pResult, pUserData, WEAPON_RIFLE, false);
+	pSelf->ModifyWeapons(pResult, pUserData, WEAPON_LASER, false);
 }
 
 void CGameContext::ConJetpack(IConsole::IResult *pResult, void *pUserData)
@@ -192,10 +193,10 @@ void CGameContext::ConUnGrenade(IConsole::IResult *pResult, void *pUserData)
 	pSelf->ModifyWeapons(pResult, pUserData, WEAPON_GRENADE, true);
 }
 
-void CGameContext::ConUnRifle(IConsole::IResult *pResult, void *pUserData)
+void CGameContext::ConUnLaser(IConsole::IResult *pResult, void *pUserData)
 {
 	CGameContext *pSelf = (CGameContext *) pUserData;
-	pSelf->ModifyWeapons(pResult, pUserData, WEAPON_RIFLE, true);
+	pSelf->ModifyWeapons(pResult, pUserData, WEAPON_LASER, true);
 }
 
 void CGameContext::ConUnJetpack(IConsole::IResult *pResult, void *pUserData)
@@ -243,7 +244,7 @@ void CGameContext::ModifyWeapons(IConsole::IResult *pResult, void *pUserData,
 	{
 		pChr->GiveWeapon(WEAPON_SHOTGUN, Remove);
 		pChr->GiveWeapon(WEAPON_GRENADE, Remove);
-		pChr->GiveWeapon(WEAPON_RIFLE, Remove);
+		pChr->GiveWeapon(WEAPON_LASER, Remove);
 	}
 	else
 	{
@@ -639,20 +640,6 @@ void CGameContext::ConModerate(IConsole::IResult *pResult, void *pUserData)
 		pSelf->SendChatTarget(pResult->m_ClientID, "Active moderator mode disabled for you.");
 }
 
-void CGameContext::ConList(IConsole::IResult *pResult, void *pUserData)
-{
-	CGameContext *pSelf = (CGameContext *)pUserData;
-	int ClientID = pResult->m_ClientID;
-	if(!CheckClientID(ClientID)) return;
-
-	char zerochar = 0;
-	if(pResult->NumArguments() > 0)
-		pSelf->List(ClientID, pResult->GetString(0));
-	else
-		pSelf->List(ClientID, &zerochar);
-}
-
-
 void CGameContext::ConSetDDRTeam(IConsole::IResult *pResult, void *pUserData)
 {
 	CGameContext *pSelf = (CGameContext *)pUserData;
@@ -719,3 +706,28 @@ void CGameContext::ConVoteNo(IConsole::IResult *pResult, void *pUserData)
 
 	pSelf->ForceVote(pResult->m_ClientID, false);
 }
+
+void CGameContext::ConDrySave(IConsole::IResult *pResult, void *pUserData)
+{
+	CGameContext *pSelf = (CGameContext *)pUserData;
+
+	CPlayer *pPlayer = pSelf->m_apPlayers[pResult->m_ClientID];
+
+	if(!pPlayer || pSelf->Server()->GetAuthedState(pResult->m_ClientID) != AUTHED_ADMIN)
+		return;
+
+	CSaveTeam SavedTeam(pSelf->m_pController);
+	int Result = SavedTeam.save(pPlayer->GetTeam());
+	if(CSaveTeam::HandleSaveError(Result, pResult->m_ClientID, pSelf))
+		return;
+
+	char aBuf[64];
+	str_format(aBuf, sizeof(aBuf), "%s-%lld-%s.save", pSelf->Server()->GetMapName(), time_get(), pSelf->Server()->GetAuthName(pResult->m_ClientID));
+	IOHANDLE File = pSelf->Storage()->OpenFile(aBuf, IOFLAG_WRITE, IStorage::TYPE_ALL);
+	if(!File)
+		return;
+
+	int Len = str_length(SavedTeam.GetString());
+	io_write(File, SavedTeam.GetString(), Len);
+	io_close(File);
+}
