@@ -67,10 +67,12 @@ TEST(Str, Utf8ToLower)
 	EXPECT_TRUE(str_utf8_comp_nocase("ÖlÜ", "ölüa") < 0); // NULL < a
 	EXPECT_TRUE(str_utf8_comp_nocase("ölüa", "ÖlÜ") > 0); // a < NULL
 
-	const char a[2] = {-128, 0};
+#if (CHAR_MIN < 0)
+	const char a[2] = {CHAR_MIN, 0};
 	const char b[2] = {0, 0};
 	EXPECT_TRUE(str_utf8_comp_nocase(a, b) > 0);
 	EXPECT_TRUE(str_utf8_comp_nocase(b, a) < 0);
+#endif
 
 	EXPECT_TRUE(str_utf8_comp_nocase_num("ÖlÜ", "ölüa", 5) == 0);
 	EXPECT_TRUE(str_utf8_comp_nocase_num("ÖlÜ", "ölüa", 6) != 0);
@@ -136,6 +138,24 @@ TEST(Str, HexDecode)
 	EXPECT_EQ(str_hex_decode(aOut, 4, "41424344"), 0); EXPECT_STREQ(aOut, "ABCD");
 }
 
+TEST(Str, Tokenize)
+{
+	char aTest[] = "GER,RUS,ZAF,BRA,CAN";
+	const char *aOut[] = {"GER", "RUS", "ZAF", "BRA", "CAN"};
+	char aBuf[4];
+
+	int n = 0;
+	for(const char *tok = aTest; (tok = str_next_token(tok, ",", aBuf, sizeof(aBuf)));)
+		EXPECT_STREQ(aOut[n++], aBuf);
+
+	char aTest2[] = "";
+	EXPECT_EQ(str_next_token(aTest2, ",", aBuf, sizeof(aBuf)), nullptr);
+
+	char aTest3[] = "+b";
+	str_next_token(aTest3, "+", aBuf, sizeof(aBuf));
+	EXPECT_STREQ(aBuf, "b");
+}
+
 TEST(Str, InList)
 {
 	char aTest[] = "GER,RUS,ZAF,BRA,CAN";
@@ -151,4 +171,31 @@ TEST(Str, InList)
 	EXPECT_FALSE(str_in_list("abc,xyz", ",", "abcdef"));
 	EXPECT_FALSE(str_in_list("", ",", ""));
 	EXPECT_FALSE(str_in_list("", ",", "xyz"));
+
+	EXPECT_TRUE(str_in_list("FOO,,BAR", ",", ""));
+}
+
+TEST(Str, StrFormat)
+{
+	char aBuf[4];
+	EXPECT_EQ(str_format(aBuf, 4, "%d:", 9), 2);
+	EXPECT_STREQ(aBuf, "9:");
+	EXPECT_EQ(str_format(aBuf, 4, "%d: ", 9), 3);
+	EXPECT_STREQ(aBuf, "9: ");
+	EXPECT_EQ(str_format(aBuf, 4, "%d: ", 99), 3);
+	EXPECT_STREQ(aBuf, "99:");
+}
+
+TEST(Str, StrCopyNum)
+{
+	const char *foo = "Foobar";
+	char aBuf[64];
+	str_truncate(aBuf, 3, foo, 1);
+	EXPECT_STREQ(aBuf, "F");
+	str_truncate(aBuf, 3, foo, 2);
+	EXPECT_STREQ(aBuf, "Fo");
+	str_truncate(aBuf, 3, foo, 3);
+	EXPECT_STREQ(aBuf, "Fo");
+	str_truncate(aBuf, sizeof(aBuf), foo, 6);
+	EXPECT_STREQ(aBuf, "Foobar");
 }
